@@ -9,30 +9,38 @@ and ``with_pattern()`` when ``import \*`` is used:
 
 From there it's a simple thing to parse a string:
 
->>> parse("It's {}, I love it!", "It's spam, I love it!")
-<Result ('spam',) {}>
->>> _[0]
-'spam'
+.. code-block:: pycon
+
+    >>> parse("It's {}, I love it!", "It's spam, I love it!")
+    <Result ('spam',) {}>
+    >>> _[0]
+    'spam'
 
 Or to search a string for some pattern:
 
->>> search('Age: {:d}\n', 'Name: Rufus\nAge: 42\nColor: red\n')
-<Result (42,) {}>
+.. code-block:: pycon
+
+    >>> search('Age: {:d}\n', 'Name: Rufus\nAge: 42\nColor: red\n')
+    <Result (42,) {}>
 
 Or find all the occurrences of some pattern in a string:
 
->>> ''.join(r[0] for r in findall(">{}<", "<p>the <b>bold</b> text</p>"))
-'the bold text'
+.. code-block:: pycon
+
+    >>> ''.join(r[0] for r in findall(">{}<", "<p>the <b>bold</b> text</p>"))
+    'the bold text'
 
 If you're going to use the same pattern to match lots of strings you can
 compile it once:
 
->>> from parse import compile
->>> p = compile("It's {}, I love it!")
->>> print(p)
-<Parser "It's {}, I love it!">
->>> p.parse("It's spam, I love it!")
-<Result ('spam',) {}>
+.. code-block:: pycon
+
+    >>> from parse import compile
+    >>> p = compile("It's {}, I love it!")
+    >>> print(p)
+    <Parser "It's {}, I love it!">
+    >>> p.parse("It's spam, I love it!")
+    <Result ('spam',) {}>
 
 ("compile" is not exported for ``import *`` usage as it would override the
 built-in ``compile()`` function)
@@ -40,8 +48,10 @@ built-in ``compile()`` function)
 The default behaviour is to match strings case insensitively. You may match with
 case by specifying `case_sensitive=True`:
 
->>> parse('SPAM', 'spam', case_sensitive=True) is None
-True
+.. code-block:: pycon
+
+    >>> parse('SPAM', 'spam', case_sensitive=True) is None
+    True
 
 
 Format Syntax
@@ -64,40 +74,44 @@ There are no "!" field conversions like ``format()`` has.
 
 Some simple parse() format string examples:
 
->>> parse("Bring me a {}", "Bring me a shrubbery")
-<Result ('shrubbery',) {}>
->>> r = parse("The {} who say {}", "The knights who say Ni!")
->>> print(r)
-<Result ('knights', 'Ni!') {}>
->>> print(r.fixed)
-('knights', 'Ni!')
->>> r = parse("Bring out the holy {item}", "Bring out the holy hand grenade")
->>> print(r)
-<Result () {'item': 'hand grenade'}>
->>> print(r.named)
-{'item': 'hand grenade'}
->>> print(r['item'])
-hand grenade
->>> 'item' in r
-True
+.. code-block:: pycon
+
+    >>> parse("Bring me a {}", "Bring me a shrubbery")
+    <Result ('shrubbery',) {}>
+    >>> r = parse("The {} who say {}", "The knights who say Ni!")
+    >>> print(r)
+    <Result ('knights', 'Ni!') {}>
+    >>> print(r.fixed)
+    ('knights', 'Ni!')
+    >>> r = parse("Bring out the holy {item}", "Bring out the holy hand grenade")
+    >>> print(r)
+    <Result () {'item': 'hand grenade'}>
+    >>> print(r.named)
+    {'item': 'hand grenade'}
+    >>> print(r['item'])
+    hand grenade
+    >>> 'item' in r
+    True
 
 Note that `in` only works if you have named fields. Dotted names and indexes
 are possible though the application must make additional sense of the result:
 
->>> r = parse("Mmm, {food.type}, I love it!", "Mmm, spam, I love it!")
->>> print(r)
-<Result () {'food.type': 'spam'}>
->>> print(r.named)
-{'food.type': 'spam'}
->>> print(r['food.type'])
-spam
->>> r = parse("My quest is {quest[name]}", "My quest is to seek the holy grail!")
->>> print(r)
-<Result () {'quest': {'name': 'to seek the holy grail!'}}>
->>> print(r['quest'])
-{'name': 'to seek the holy grail!'}
->>> print(r['quest']['name'])
-to seek the holy grail!
+.. code-block:: pycon
+
+    >>> r = parse("Mmm, {food.type}, I love it!", "Mmm, spam, I love it!")
+    >>> print(r)
+    <Result () {'food.type': 'spam'}>
+    >>> print(r.named)
+    {'food.type': 'spam'}
+    >>> print(r['food.type'])
+    spam
+    >>> r = parse("My quest is {quest[name]}", "My quest is to seek the holy grail!")
+    >>> print(r)
+    <Result () {'quest': {'name': 'to seek the holy grail!'}}>
+    >>> print(r['quest'])
+    {'name': 'to seek the holy grail!'}
+    >>> print(r['quest']['name'])
+    to seek the holy grail!
 
 If the text you're matching has braces in it you can match those by including
 a double-brace ``{{`` or ``}}`` in your format string, just like format() does.
@@ -174,18 +188,22 @@ tt    Time                                        time
 Some examples of typed parsing with ``None`` returned if the typing
 does not match:
 
->>> parse('Our {:d} {:w} are...', 'Our 3 weapons are...')
-<Result (3, 'weapons') {}>
->>> parse('Our {:d} {:w} are...', 'Our three weapons are...')
->>> parse('Meet at {:tg}', 'Meet at 1/2/2011 11:00 PM')
-<Result (datetime.datetime(2011, 2, 1, 23, 0),) {}>
+.. code-block:: pycon
+
+    >>> parse('Our {:d} {:w} are...', 'Our 3 weapons are...')
+    <Result (3, 'weapons') {}>
+    >>> parse('Our {:d} {:w} are...', 'Our three weapons are...')
+    >>> parse('Meet at {:tg}', 'Meet at 1/2/2011 11:00 PM')
+    <Result (datetime.datetime(2011, 2, 1, 23, 0),) {}>
 
 And messing about with alignment:
 
->>> parse('with {:>} herring', 'with     a herring')
-<Result ('a',) {}>
->>> parse('spam {:^} spam', 'spam    lovely     spam')
-<Result ('lovely',) {}>
+.. code-block:: pycon
+
+    >>> parse('with {:>} herring', 'with     a herring')
+    <Result ('a',) {}>
+    >>> parse('spam {:^} spam', 'spam    lovely     spam')
+    <Result ('lovely',) {}>
 
 Note that the "center" alignment does not test to make sure the value is
 centered - it just strips leading and trailing whitespace.
@@ -194,14 +212,16 @@ Width and precision may be used to restrict the size of matched text
 from the input. Width specifies a minimum size and precision specifies
 a maximum. For example:
 
->>> parse('{:.2}{:.2}', 'look')           # specifying precision
-<Result ('lo', 'ok') {}>
->>> parse('{:4}{:4}', 'look at that')     # specifying width
-<Result ('look', 'at that') {}>
->>> parse('{:4}{:.4}', 'look at that')    # specifying both
-<Result ('look at ', 'that') {}>
->>> parse('{:2d}{:2d}', '0440')           # parsing two contiguous numbers
-<Result (4, 40) {}>
+.. code-block:: pycon
+
+    >>> parse('{:.2}{:.2}', 'look')           # specifying precision
+    <Result ('lo', 'ok') {}>
+    >>> parse('{:4}{:4}', 'look at that')     # specifying width
+    <Result ('look', 'at that') {}>
+    >>> parse('{:4}{:.4}', 'look at that')    # specifying both
+    <Result ('look at ', 'that') {}>
+    >>> parse('{:2d}{:2d}', '0440')           # parsing two contiguous numbers
+    <Result (4, 40) {}>
 
 Some notes for the date and time types:
 
@@ -246,18 +266,18 @@ The result of a ``parse()`` and ``search()`` operation is either ``None`` (no ma
 
 The ``Result`` instance has three attributes:
 
-fixed
+``fixed``
    A tuple of the fixed-position, anonymous fields extracted from the input.
-named
+``named``
    A dictionary of the named fields extracted from the input.
-spans
+``spans``
    A dictionary mapping the names and fixed position indices matched to a
    2-tuple slice range of where the match occurred in the input.
    The span does not include any stripped padding (alignment or width).
 
 The ``Match`` instance has one method:
 
-evaluate_result()
+``evaluate_result()``
    Generates and returns a ``Result`` instance for this ``Match`` object.
 
 
@@ -273,56 +293,66 @@ The converter will be passed the field string matched. Whatever it returns
 will be substituted in the ``Result`` instance for that field.
 
 Your custom type conversions may override the builtin types if you supply one
-with the same identifier.
+with the same identifier:
 
->>> def shouty(string):
-...    return string.upper()
-...
->>> parse('{:shouty} world', 'hello world', dict(shouty=shouty))
-<Result ('HELLO',) {}>
+.. code-block:: pycon
+
+    >>> def shouty(string):
+    ...    return string.upper()
+    ...
+    >>> parse('{:shouty} world', 'hello world', dict(shouty=shouty))
+    <Result ('HELLO',) {}>
 
 If the type converter has the optional ``pattern`` attribute, it is used as
-regular expression for better pattern matching (instead of the default one).
+regular expression for better pattern matching (instead of the default one):
 
->>> def parse_number(text):
-...    return int(text)
->>> parse_number.pattern = r'\d+'
->>> parse('Answer: {number:Number}', 'Answer: 42', dict(Number=parse_number))
-<Result () {'number': 42}>
->>> _ = parse('Answer: {:Number}', 'Answer: Alice', dict(Number=parse_number))
->>> assert _ is None, "MISMATCH"
+.. code-block:: pycon
+
+    >>> def parse_number(text):
+    ...    return int(text)
+    >>> parse_number.pattern = r'\d+'
+    >>> parse('Answer: {number:Number}', 'Answer: 42', dict(Number=parse_number))
+    <Result () {'number': 42}>
+    >>> _ = parse('Answer: {:Number}', 'Answer: Alice', dict(Number=parse_number))
+    >>> assert _ is None, "MISMATCH"
 
 You can also use the ``with_pattern(pattern)`` decorator to add this
 information to a type converter function:
 
->>> from parse import with_pattern
->>> @with_pattern(r'\d+')
-... def parse_number(text):
-...    return int(text)
->>> parse('Answer: {number:Number}', 'Answer: 42', dict(Number=parse_number))
-<Result () {'number': 42}>
+.. code-block:: pycon
+
+    >>> from parse import with_pattern
+    >>> @with_pattern(r'\d+')
+    ... def parse_number(text):
+    ...    return int(text)
+    >>> parse('Answer: {number:Number}', 'Answer: 42', dict(Number=parse_number))
+    <Result () {'number': 42}>
 
 A more complete example of a custom type might be:
 
->>> yesno_mapping = {
-...     "yes":  True,   "no":    False,
-...     "on":   True,   "off":   False,
-...     "true": True,   "false": False,
-... }
->>> @with_pattern(r"|".join(yesno_mapping))
-... def parse_yesno(text):
-...     return yesno_mapping[text.lower()]
+.. code-block:: pycon
+
+    >>> yesno_mapping = {
+    ...     "yes":  True,   "no":    False,
+    ...     "on":   True,   "off":   False,
+    ...     "true": True,   "false": False,
+    ... }
+    >>> @with_pattern(r"|".join(yesno_mapping))
+    ... def parse_yesno(text):
+    ...     return yesno_mapping[text.lower()]
 
 
 If the type converter ``pattern`` uses regex-grouping (with parenthesis),
 you should indicate this by using the optional ``regex_group_count`` parameter
 in the ``with_pattern()`` decorator:
 
->>> @with_pattern(r'((\d+))', regex_group_count=2)
-... def parse_number2(text):
-...    return int(text)
->>> parse('Answer: {:Number2} {:Number2}', 'Answer: 42 43', dict(Number2=parse_number2))
-<Result (42, 43) {}>
+.. code-block:: pycon
+
+    >>> @with_pattern(r'((\d+))', regex_group_count=2)
+    ... def parse_number2(text):
+    ...    return int(text)
+    >>> parse('Answer: {:Number2} {:Number2}', 'Answer: 42 43', dict(Number2=parse_number2))
+    <Result (42, 43) {}>
 
 Otherwise, this may cause parsing problems with unnamed/fixed parameters.
 
@@ -330,22 +360,26 @@ Otherwise, this may cause parsing problems with unnamed/fixed parameters.
 Potential Gotchas
 -----------------
 
-`parse()` will always match the shortest text necessary (from left to right)
+``parse()`` will always match the shortest text necessary (from left to right)
 to fulfil the parse pattern, so for example:
 
->>> pattern = '{dir1}/{dir2}'
->>> data = 'root/parent/subdir'
->>> sorted(parse(pattern, data).named.items())
-[('dir1', 'root'), ('dir2', 'parent/subdir')]
+
+.. code-block:: pycon
+
+    >>> pattern = '{dir1}/{dir2}'
+    >>> data = 'root/parent/subdir'
+    >>> sorted(parse(pattern, data).named.items())
+    [('dir1', 'root'), ('dir2', 'parent/subdir')]
 
 So, even though `{'dir1': 'root/parent', 'dir2': 'subdir'}` would also fit
 the pattern, the actual match represents the shortest successful match for
-`dir1`.
+``dir1``.
 
 ----
 
 **Version history (in brief)**:
 
+- 1.16.0 Make compiled parse objects pickleable (thanks @martinResearch)
 - 1.15.0 Several fixes for parsing non-base 10 numbers (thanks @vladikcomper)
 - 1.14.0 More broad acceptance of Fortran number format (thanks @purpleskyfall)
 - 1.13.1 Project metadata correction.
@@ -419,12 +453,12 @@ the pattern, the actual match represents the shortest successful match for
   and removed the restriction on mixing fixed-position and named fields
 - 1.0.0 initial release
 
-This code is copyright 2012-2019 Richard Jones <richard@python.org>
+This code is copyright 2012-2020 Richard Jones <richard@python.org>
 See the end of the source file for the license of use.
 '''
 
 from __future__ import absolute_import
-__version__ = '1.15.0'
+__version__ = '1.16.0'
 
 # yes, I now have two problems
 import re
@@ -468,7 +502,7 @@ def with_pattern(pattern, regex_group_count=None):
     return decorator
 
 
-def int_convert(base=None):
+class int_convert:
     '''Convert a string to an integer.
 
     The string may start with a sign.
@@ -476,14 +510,19 @@ def int_convert(base=None):
     It may be of a base other than 2, 8, 10 or 16.
 
     If base isn't specified, it will be detected automatically based
-    on a string format. When string starts with a base indicator, 0#nnnn, 
+    on a string format. When string starts with a base indicator, 0#nnnn,
     it overrides the default base of 10.
 
     It may also have other non-numeric characters that we can ignore.
-    '''
+    '''    
+
     CHARS = '0123456789abcdefghijklmnopqrstuvwxyz'
 
-    def f(string, match, base=base):
+    def __init__(self, base=None):
+        self.base = base
+      
+
+    def __call__(self, string, match):
         if string[0] == '-':
             sign = -1
             number_start = 1
@@ -495,24 +534,32 @@ def int_convert(base=None):
             number_start = 0
 
         # If base wasn't specified, detect it automatically
-        if base is None:
+        if self.base is None:
 
           # Assume decimal number, unless different base is detected
-          base = 10
+          self.base = 10
 
           # For number formats starting with 0b, 0o, 0x, use corresponding base ...
           if string[number_start] == '0' and len(string) - number_start > 2:
               if string[number_start+1] in 'bB':
-                  base = 2
+                  self.base = 2
               elif string[number_start+1] in 'oO':
-                  base = 8
+                  self.base = 8
               elif string[number_start+1] in 'xX':
-                  base = 16
+                  self.base = 16
 
-        chars = CHARS[:base]
+        chars = int_convert.CHARS[:self.base]
         string = re.sub('[^%s]' % chars, '', string.lower())
-        return sign * int(string, base)
-    return f
+        return sign * int(string, self.base)
+ 
+class convert_first:
+    """Convert the first element of a pair.     
+    This equivalent to lambda s,m: converter(s). But unlike a lambda function, it can be pickled
+    """
+    def __init__(self, converter):
+        self.converter = converter
+    def __call__(self, string, match):
+        return self.converter(string)
 
 
 def percentage(string, match):
@@ -986,10 +1033,7 @@ class Parser(object):
             if regex_group_count is None:
                 regex_group_count = 0
             self._group_index += regex_group_count
-
-            def f(string, m):
-                return type_converter(string)
-            self._type_conversions[group] = f
+            self._type_conversions[group] = convert_first(type_converter)
         elif type == 'n':
             s = r'\d{1,3}([,.]\d{3})*'
             self._group_index += 1
@@ -1012,24 +1056,24 @@ class Parser(object):
             self._type_conversions[group] = percentage
         elif type == 'f':
             s = r'\d*\.\d+'
-            self._type_conversions[group] = lambda s, m: float(s)
+            self._type_conversions[group] = convert_first(float)
         elif type == 'F':
             s = r'\d*\.\d+'
-            self._type_conversions[group] = lambda s, m: Decimal(s)
+            self._type_conversions[group] = convert_first(Decimal)
         elif type == 'e':
             s = r'\d*\.\d+[eE][-+]?\d+|nan|NAN|[-+]?inf|[-+]?INF'
-            self._type_conversions[group] = lambda s, m: float(s)
+            self._type_conversions[group] = convert_first(float)
         elif type == 'g':
             s = r'\d+(\.\d+)?([eE][-+]?\d+)?|nan|NAN|[-+]?inf|[-+]?INF'
             self._group_index += 2
-            self._type_conversions[group] = lambda s, m: float(s)
+            self._type_conversions[group] = convert_first(float)
         elif type == 'd':
             if format.get('width'):
                 width = r'{1,%s}' % int(format['width'])
             else:
                 width = '+'
             s = r'\d{w}|[-+ ]?0[xX][0-9a-fA-F]{w}|[-+ ]?0[bB][01]{w}|[-+ ]?0[oO][0-7]{w}'.format(w=width)
-            self._type_conversions[group] = int_convert() # do not specify numeber base, determine it automatically
+            self._type_conversions[group] = int_convert() # do not specify number base, determine it automatically
         elif type == 'ti':
             s = r'(\d{4}-\d\d-\d\d)((\s+|T)%s)?(Z|\s*[-+]\d\d:?\d\d)?' % \
                 TIME_PAT
